MethodChannelFlutterScreenShare class

An implementation of FlutterScreenSharePlatform that uses method channels.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getDisplays() → Future<List<Display>>
Get available displays
override
getSources() → Future<List<Display>>
override
getStream() → Stream<Uint8List>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startCapture([Display? source, EncodingOptions? options]) → Future<Map>
Start screen capture and return a stream of frame data
override
stopCapture() → Future<void>
Stop screen capture
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited