FlutterScreenSharePlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • FlutterScreenSharePlatform
Implementers

Constructors

FlutterScreenSharePlatform()
Constructs a FlutterScreenSharePlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getDisplays() → Future<List<Display>>
getSources() → Future<List<Display>>
getStream() → Stream<Uint8List>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startCapture([Display? source, EncodingOptions? options]) → Future<Map>
stopCapture() → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ FlutterScreenSharePlatform
The default instance of FlutterScreenSharePlatform to use.
getter/setter pair